==> zio-aws-codecommit_3-5.17.130.1-sources.jar: zio/aws/codecommit/model/PostCommentReplyResponse.scala <==
package zio.aws.codecommit.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PostCommentReplyResponse(
    comment: Option[zio.aws.codecommit.model.Comment] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse = {
    import PostCommentReplyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
      .builder()
      .optionallyWith(comment.map(value => value.buildAwsValue()))(_.comment)
      .build()
  }
  def asReadOnly: zio.aws.codecommit.model.PostCommentReplyResponse.ReadOnly =
    zio.aws.codecommit.model.PostCommentReplyResponse.wrap(buildAwsValue())
}
object PostCommentReplyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecommit.model.PostCommentReplyResponse =
      zio.aws.codecommit.model
        .PostCommentReplyResponse(comment.map(value => value.asEditable))
    def comment: Option[zio.aws.codecommit.model.Comment.ReadOnly]
    def getComment
        : ZIO[Any, AwsError, zio.aws.codecommit.model.Comment.ReadOnly] =
      AwsError.unwrapOptionField("comment", comment)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
  ) extends zio.aws.codecommit.model.PostCommentReplyResponse.ReadOnly {
    override val comment: Option[zio.aws.codecommit.model.Comment.ReadOnly] =
      scala
        .Option(impl.comment())
        .map(value => zio.aws.codecommit.model.Comment.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
  ): zio.aws.codecommit.model.PostCommentReplyResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-codecommit_3-5.17.182.1-sources.jar: zio/aws/codecommit/model/PostCommentReplyResponse.scala <==
package zio.aws.codecommit.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class PostCommentReplyResponse(
    comment: Optional[zio.aws.codecommit.model.Comment] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse = {
    import PostCommentReplyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
      .builder()
      .optionallyWith(comment.map(value => value.buildAwsValue()))(_.comment)
      .build()
  }
  def asReadOnly: zio.aws.codecommit.model.PostCommentReplyResponse.ReadOnly =
    zio.aws.codecommit.model.PostCommentReplyResponse.wrap(buildAwsValue())
}
object PostCommentReplyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecommit.model.PostCommentReplyResponse =
      zio.aws.codecommit.model
        .PostCommentReplyResponse(comment.map(value => value.asEditable))
    def comment: Optional[zio.aws.codecommit.model.Comment.ReadOnly]
    def getComment
        : ZIO[Any, AwsError, zio.aws.codecommit.model.Comment.ReadOnly] =
      AwsError.unwrapOptionField("comment", comment)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
  ) extends zio.aws.codecommit.model.PostCommentReplyResponse.ReadOnly {
    override val comment: Optional[zio.aws.codecommit.model.Comment.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.comment())
        .map(value => zio.aws.codecommit.model.Comment.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecommit.model.PostCommentReplyResponse
  ): zio.aws.codecommit.model.PostCommentReplyResponse.ReadOnly = new Wrapper(
    impl
  )
}
